package examples;

import java.io.IOException;

import org.apache.cassandra.thrift.Cassandra;
import org.apache.cassandra.thrift.Column;
import org.apache.cassandra.thrift.ColumnOrSuperColumn;
import org.apache.cassandra.thrift.ColumnPath;
import org.apache.cassandra.thrift.ConsistencyLevel;
import org.apache.cassandra.thrift.InvalidRequestException;
import org.apache.cassandra.thrift.NotFoundException;
import org.apache.cassandra.thrift.TimedOutException;
import org.apache.cassandra.thrift.UnavailableException;
import org.apache.thrift.TException;
import org.apache.thrift.protocol.TBinaryProtocol;
import org.apache.thrift.protocol.TProtocol;
import org.apache.thrift.transport.TSocket;
import org.apache.thrift.transport.TTransportException;

/**
 * 郵便番号に対しての住所を検索する.
 */
public class SimpleAddressSearchOne {

	public static final String KEYSPACE = "Keyspace1";

	public static final String COLUMN_FAMILY = "SimpleAddress";

	public static void main(String[] args) throws IOException {
		TSocket transport = new TSocket("localhost", 9160);
		TProtocol protocol = new TBinaryProtocol(transport);
		try {
			transport.open();
		} catch (TTransportException e) {
			throw new RuntimeException(e);
		}
		try {
			Cassandra.Client client = new Cassandra.Client(protocol);

			String key = "1006528";

			ColumnPath path = new ColumnPath(COLUMN_FAMILY);
			path.setColumn("address".getBytes());

			// キーに対する住所を取得する.
			ColumnOrSuperColumn csc = client.get(KEYSPACE, key, path,
					ConsistencyLevel.ONE);

			// カラムファミリSimpleAddressはカラムのみを保存するのでシンプルにgetColumn()する.
			Column c = csc.getColumn();
			String name = new String(c.getName());
			String value = new String(c.getValue());

			System.out.println(name + " -> " + value + "(" + c.getTimestamp()
					+ ")");
		} catch (InvalidRequestException e) {
			throw new RuntimeException(e);
		} catch (UnavailableException e) {
			throw new RuntimeException(e);
		} catch (TimedOutException e) {
			throw new RuntimeException(e);
		} catch (TException e) {
			throw new RuntimeException(e);
		} catch (NotFoundException e) {
			e.printStackTrace();
		} finally {
			try {
				transport.flush();
			} catch (TTransportException e) {
				throw new RuntimeException(e);
			} finally {
				transport.close();
			}
		}
	}
}
