package examples;

import java.io.IOException;
import java.util.Arrays;
import java.util.List;

import org.apache.cassandra.thrift.Cassandra;
import org.apache.cassandra.thrift.Column;
import org.apache.cassandra.thrift.ColumnOrSuperColumn;
import org.apache.cassandra.thrift.ColumnParent;
import org.apache.cassandra.thrift.ConsistencyLevel;
import org.apache.cassandra.thrift.InvalidRequestException;
import org.apache.cassandra.thrift.SlicePredicate;
import org.apache.cassandra.thrift.TimedOutException;
import org.apache.cassandra.thrift.UnavailableException;
import org.apache.thrift.TException;
import org.apache.thrift.protocol.TBinaryProtocol;
import org.apache.thrift.protocol.TProtocol;
import org.apache.thrift.transport.TSocket;
import org.apache.thrift.transport.TTransportException;

/**
 * ある郵便番号に対して、住所を検索する.
 */
public class SimpleAddressSearchSlice1 {

	public static final String KEYSPACE = "Keyspace1";

	public static final String COLUMN_FAMILY = "SimpleAddress";

	public static void main(String[] args) throws IOException {
		TSocket transport = new TSocket("localhost", 9160);
		TProtocol protocol = new TBinaryProtocol(transport);
		try {
			transport.open();
		} catch (TTransportException e) {
			throw new RuntimeException(e);
		}
		try {
			Cassandra.Client client = new Cassandra.Client(protocol);
			ColumnParent parent = new ColumnParent(COLUMN_FAMILY);
			String key = "1006528";

			// カラムの指定. 郵便番号と住所を指定する.
			SlicePredicate predicate = new SlicePredicate();
			predicate.setColumn_names(Arrays.asList("postalCode".getBytes(),
					"address".getBytes()));

			List<ColumnOrSuperColumn> ret = client.get_slice(KEYSPACE, key,
					parent, predicate, ConsistencyLevel.ONE);

			/**
			 * 結果を表示.
			 * 結果のソート順序は、storage-conf.xmlで定義したSimpleAddressのCompareWith属性どおり.
			 * 今回はUTF8指定しているので、address、postalCodeの順序になる.
			 */
			for (ColumnOrSuperColumn csc : ret) {
				Column column = csc.getColumn();
				String name = new String(column.getName());
				String value = new String(column.getValue());

				System.out.println("\t" + name + " -> " + value + "("
						+ column.getTimestamp() + ")");
			}
		} catch (InvalidRequestException e) {
			throw new RuntimeException(e);
		} catch (UnavailableException e) {
			throw new RuntimeException(e);
		} catch (TimedOutException e) {
			throw new RuntimeException(e);
		} catch (TException e) {
			throw new RuntimeException(e);
		} finally {
			try {
				transport.flush();
			} catch (TTransportException e) {
				throw new RuntimeException(e);
			} finally {
				transport.close();
			}
		}
	}
}
