package examples;

import java.io.IOException;
import java.util.List;

import org.apache.cassandra.thrift.Cassandra;
import org.apache.cassandra.thrift.Column;
import org.apache.cassandra.thrift.ColumnOrSuperColumn;
import org.apache.cassandra.thrift.ColumnParent;
import org.apache.cassandra.thrift.ConsistencyLevel;
import org.apache.cassandra.thrift.InvalidRequestException;
import org.apache.cassandra.thrift.SlicePredicate;
import org.apache.cassandra.thrift.SliceRange;
import org.apache.cassandra.thrift.TimedOutException;
import org.apache.cassandra.thrift.UnavailableException;
import org.apache.thrift.TException;
import org.apache.thrift.protocol.TBinaryProtocol;
import org.apache.thrift.protocol.TProtocol;
import org.apache.thrift.transport.TSocket;
import org.apache.thrift.transport.TTransportException;

/**
 * 郵便番号から、カラム名のレンジで決められた幾つかの情報を降順で検索する.
 */
public class SimpleAddressSearchSlice3_Reversed {

	public static final String KEYSPACE = "Keyspace1";

	public static final String COLUMN_FAMILY = "SimpleAddress";

	public static void main(String[] args) throws IOException {
		TSocket transport = new TSocket("localhost", 9160);
		TProtocol protocol = new TBinaryProtocol(transport);
		try {
			transport.open();
		} catch (TTransportException e) {
			throw new RuntimeException(e);
		}
		try {
			Cassandra.Client client = new Cassandra.Client(protocol);
			ColumnParent parent = new ColumnParent(COLUMN_FAMILY);

			String key = "1006528";

			SlicePredicate predicate = new SlicePredicate();

			// 項目の中から、addressからpostalCodeまでのレンジに入る項目を抽出.
			SliceRange range = new SliceRange();
			range.setStart("postalCode".getBytes());
			range.setFinish("addressYomi".getBytes());
			range.setReversed(true);
			predicate.setSlice_range(range);

			List<ColumnOrSuperColumn> ret = client.get_slice(KEYSPACE, key,
					parent, predicate, ConsistencyLevel.ONE);

			System.out.println("SliceRangeでカラムを絞った場合");
			for (ColumnOrSuperColumn csc : ret) {
				Column column = csc.getColumn();
				String name = new String(column.getName());
				String value = new String(column.getValue());

				System.out.println("\t" + name + " -> " + value + "("
						+ column.getTimestamp() + ")");
			}

			System.out.println("SliceRangeでカラムを絞らなかった場合");
			SliceRange rangeAll = new SliceRange();
			rangeAll.setStart("".getBytes());
			rangeAll.setFinish("".getBytes());
			rangeAll.setReversed(true);
			predicate.setSlice_range(rangeAll);

			ret = client.get_slice(KEYSPACE, key, parent, predicate,
					ConsistencyLevel.ONE);

			for (ColumnOrSuperColumn csc : ret) {
				Column column = csc.getColumn();
				String name = new String(column.getName());
				String value = new String(column.getValue());

				System.out.println("\t" + name + " -> " + value + "("
						+ column.getTimestamp() + ")");
			}

		} catch (InvalidRequestException e) {
			throw new RuntimeException(e);
		} catch (UnavailableException e) {
			throw new RuntimeException(e);
		} catch (TimedOutException e) {
			throw new RuntimeException(e);
		} catch (TException e) {
			throw new RuntimeException(e);
		} finally {
			try {
				transport.flush();
			} catch (TTransportException e) {
				throw new RuntimeException(e);
			} finally {
				transport.close();
			}
		}
	}
}
